function varargout = dmc_extractor_gui(varargin)
% DMC_EXTRACTOR_GUI M-file for dmc_extractor_gui.fig
%      DMC_EXTRACTOR_GUI, by itself, creates a new DMC_EXTRACTOR_GUI or raises the existing
%      singleton*.
%
%      H = DMC_EXTRACTOR_GUI returns the handle to a new DMC_EXTRACTOR_GUI or the handle to
%      the existing singleton*.
%
%      DMC_EXTRACTOR_GUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in DMC_EXTRACTOR_GUI.M with the given input arguments.
%
%      DMC_EXTRACTOR_GUI('Property','Value',...) creates a new DMC_EXTRACTOR_GUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before dmc_extractor_gui_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to dmc_extractor_gui_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help dmc_extractor_gui

% Last Modified by GUIDE v2.5 11-Jun-2004 09:31:27

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @dmc_extractor_gui_OpeningFcn, ...
                   'gui_OutputFcn',  @dmc_extractor_gui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before dmc_extractor_gui is made visible.
function dmc_extractor_gui_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to dmc_extractor_gui (see VARARGIN)

% Choose default command line output for dmc_extractor_gui
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes dmc_extractor_gui wait for user response (see UIRESUME)
uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = dmc_extractor_gui_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles;


% --- Executes during object creation, after setting all properties.
function datadir_CreateFcn(hObject, eventdata, handles)
% hObject    handle to datadir (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function datadir_Callback(hObject, eventdata, handles)
% hObject    handle to datadir (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of datadir as text
%        str2double(get(hObject,'String')) returns contents of datadir as a double


% --- Executes during object creation, after setting all properties.
function monthstart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to monthstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in monthstart.
function monthstart_Callback(hObject, eventdata, handles)
% hObject    handle to monthstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns monthstart contents as cell array
%        contents{get(hObject,'Value')} returns selected item from monthstart


% --- Executes during object creation, after setting all properties.
function daystart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to daystart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in daystart.
function daystart_Callback(hObject, eventdata, handles)
% hObject    handle to daystart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns daystart contents as cell array
%        contents{get(hObject,'Value')} returns selected item from daystart


% --- Executes during object creation, after setting all properties.
function yearstart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to yearstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in yearstart.
function yearstart_Callback(hObject, eventdata, handles)
% hObject    handle to yearstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns yearstart contents as cell array
%        contents{get(hObject,'Value')} returns selected item from yearstart


% --- Executes during object creation, after setting all properties.
function hourstart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to hourstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in hourstart.
function hourstart_Callback(hObject, eventdata, handles)
% hObject    handle to hourstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns hourstart contents as cell array
%        contents{get(hObject,'Value')} returns selected item from hourstart


% --- Executes during object creation, after setting all properties.
function minstart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to minstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in minstart.
function minstart_Callback(hObject, eventdata, handles)
% hObject    handle to minstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns minstart contents as cell array
%        contents{get(hObject,'Value')} returns selected item from minstart


% --- Executes during object creation, after setting all properties.
function secstart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to secstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in secstart.
function secstart_Callback(hObject, eventdata, handles)
% hObject    handle to secstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns secstart contents as cell array
%        contents{get(hObject,'Value')} returns selected item from secstart


% --- Executes during object creation, after setting all properties.
function monthend_CreateFcn(hObject, eventdata, handles)
% hObject    handle to monthend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in monthend.
function monthend_Callback(hObject, eventdata, handles)
% hObject    handle to monthend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns monthend contents as cell array
%        contents{get(hObject,'Value')} returns selected item from monthend


% --- Executes during object creation, after setting all properties.
function dayend_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dayend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in dayend.
function dayend_Callback(hObject, eventdata, handles)
% hObject    handle to dayend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns dayend contents as cell array
%        contents{get(hObject,'Value')} returns selected item from dayend


% --- Executes during object creation, after setting all properties.
function yearend_CreateFcn(hObject, eventdata, handles)
% hObject    handle to yearend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in yearend.
function yearend_Callback(hObject, eventdata, handles)
% hObject    handle to yearend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns yearend contents as cell array
%        contents{get(hObject,'Value')} returns selected item from yearend


% --- Executes during object creation, after setting all properties.
function hourend_CreateFcn(hObject, eventdata, handles)
% hObject    handle to hourend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in hourend.
function hourend_Callback(hObject, eventdata, handles)
% hObject    handle to hourend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns hourend contents as cell array
%        contents{get(hObject,'Value')} returns selected item from hourend


% --- Executes during object creation, after setting all properties.
function minend_CreateFcn(hObject, eventdata, handles)
% hObject    handle to minend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in minend.
function minend_Callback(hObject, eventdata, handles)
% hObject    handle to minend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns minend contents as cell array
%        contents{get(hObject,'Value')} returns selected item from minend


% --- Executes during object creation, after setting all properties.
function secend_CreateFcn(hObject, eventdata, handles)
% hObject    handle to secend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in secend.
function secend_Callback(hObject, eventdata, handles)
% hObject    handle to secend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns secend contents as cell array
%        contents{get(hObject,'Value')} returns selected item from secend


% --- Executes on button press in compile.
function compile_Callback(hObject, eventdata, handles)
% hObject    handle to compile (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

uiresume(handles.figure1);